# Votre attention s'il vous plaît !

Cette expérience a été développé avec une version d'OpenSesame plus récente.

Je ne sais pas si ça va marcher avec cette version d'OpenSesame. Je vous recommande de mettre à jour OpenSesame. Si cela n'est pas possible, je vous recommende d'enregistrer votre expérience sous un nouveau nom.

Qu'est-ce que vous voulez faire ?

[Enregistrer l'expérience maintenant](opensesame://action.save){: .important-button} <br />

Ou vous pouvez :

[Fermer ce message pour toujours](opensesame://event.os3n_dismiss_old_experiment){: .dismiss-button}
